<?php
namespace Elementor; 
use Rekko\Elementor_widgets\Rekko_Elementor_Init as SCEW;
if ( ! defined( 'ABSPATH' ) ) exit; 

class Accordion extends Widget_Base {

	public function get_name() {
		return __( 'accordion', 'rekko-core' );
	}
	
	public function get_title() {
		return __( 'rekko-core Accordion', 'rekko-core' );
	}

	public function get_categories() {
		return [ SCEW::get_category() ];
    }

	/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-accordion';
	}

	
	public function get_script_depends() {
		return [ '' ];
	 }

	protected function register_controls() {
		$this->start_controls_section(
			'sectionadad',
			[
				'label' => __( 'Style', 'rekko-core' ),
			]
		);
		$this->add_control(
			'accordion_style',
			[
				'label' => __( 'Accordion Style', 'rekko-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1'  => __( 'Style 1', 'rekko-core' ),
				],
			]
		);

        
        $this->end_controls_section();
        
		$this->start_controls_section(
			'sectionfdf',
			[
				'label' => __( 'Accordion', 'rekko-core' ),
			]
		);

        
        
        $repeater = new Repeater();
        $repeater->add_control(
			'tab_title',
			[
				'label' => __( 'Question', 'rekko-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'What is Lorem Ipsum?', 'rekko-core' ),
				'placeholder' => __( 'Tab Title', 'rekko-core' ),
				'label_block' => true,
			]
        );
        
        $repeater->add_control(
			'tab_content',
			[
				'label' => __( 'Answer', 'rekko-core' ),
				'default' => __( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'rekko-core' ),
				'placeholder' => __( 'Tab Content', 'rekko-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'show_label' => false,
			]
        );
        

        
        $this->add_control(
			'tabs',
			[
				'label' => __( 'Tabs Items', 'rekko-core' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'tab_title' => __( 'Tab #1', 'rekko-core' ),
                        'tab_content' => __( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'rekko-core' ),
                       
					]
					
				],
				'title_field' => '{{{ tab_title }}}',
			]
        );
        $this->add_control(
			'has_icon',
			[
				'label' => __( 'Use Icon?', 'rekko-core' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'rekko-core' ),
				'no' => __( 'no', 'rekko-core' ),
			]
		);
		
		$this->add_control(
			'pilelabs_has_box_shadow',
			[
				'label' => __( 'Box Shaow?', 'rekko-core' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'rekko-core' ),
				'no' => __( 'no', 'rekko-core' ),
			]
        );
        
        $this->add_control(
			'active_icon',
			[
				'label' => __( 'Active Icon', 'rekko-core' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'ion ion-ios-arrow-down'
					
				],
				'condition' => [
					'has_icon' => 'yes',
				],
				'label_block' => false,
				'skin' => 'inline',

				
			]
		);
		$this->add_control(
			'inactive_icon',
			[
				'label' => __( 'Inactive Icon', 'rekko-core' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'ion ion-ios-arrow-up'
					
				],
				'condition' => [
					'has_icon' => 'yes',
				],
				'label_block' => false,
				'skin' => 'inline',

				
			]
		);
		$this->add_responsive_control(
			'icon_position',
			[
				'label' => __( 'Icon Position', 'rekko-core' ),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'right',
				'options' => [
					'left' => [
						'title' => __( 'Left', 'rekko-core' ),
						'icon' => 'eicon-text-align-left',
					],
					
					'right' => [
						'title' => __( 'Right', 'rekko-core' ),
						'icon' => 'eicon-text-align-right',
					],
					
                ],
                'condition' => [
					'has_icon' => 'yes',
				],
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'      => __( 'Title Tag', 'rekko-core' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'h4',
				'options'    => [
					
					'h1'          => __( 'h1', 'rekko-core' ),
					'h2'          => __( 'h2', 'rekko-core' ),
					'h3'          => __( 'h3', 'rekko-core' ),
					'h4'          => __( 'h4', 'rekko-core' ),
					'h5'          => __( 'h5', 'rekko-core' ),
					'h6'          => __( 'h6', 'rekko-core' ),
					
					
				],
			]
		);



		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Alignment', 'rekko-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'text-left' => [
						'title' => __( 'Left', 'rekko-core' ),
						'icon' => 'eicon-text-align-left',
					],
					'text-center' => [
						'title' => __( 'Center', 'rekko-core' ),
						'icon' => 'eicon-text-align-center',
					],
					'text-right' => [
						'title' => __( 'Right', 'rekko-core' ),
						'icon' => 'eicon-text-align-right',
					],
					'text-justify' => [
						'title' => __( 'Justified', 'rekko-core' ),
						'icon' => 'eicon-text-align-justify',
					],
				]
			]
		);	

        $this->end_controls_section();

        

		$this->start_controls_section(
			'section_title_style',
			[
				'label' => __( 'Title', 'rekko-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'tabs_2a0sGfU' );
         $this->start_controls_tab(
            'tabs_tJ784N2F',
            [
                'label' => __( 'Text Color', 'rekko-core' ),
            ]
        );
         $this->add_control(
			'title_colors',
			[
				'label' => __( 'Text Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-accordion-box .qwords-ad-title .ad-title-text' => 'color: {{VALUE}};',
					
				],
			]
		);

		$this->add_control(
			'title_active_color',
			[
				'label' => __( 'Text Active Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-accordion-block  .qwords-active .qwords-ad-title .ad-title-text' => 'color: {{VALUE}};',
					
				],
			]
		);
		$this->end_controls_tab();

        $this->start_controls_tab(
            'tabs__Ax450e0a',
            [
                'label' => __( 'background Color', 'rekko-core' ),
            ]
        );
        $this->add_control(
			'title_back_color',
			[
				'label' => __( 'Background Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-accordion-box .qwords-ad-title .ad-title-text' => 'background: {{VALUE}};',
					
				],
			]
		);

		$this->add_control(
			'title_back_active_color',
			[
				'label' => __( 'Active Background Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-accordion-block  .qwords-active .qwords-ad-title .ad-title-text' => 'background: {{VALUE}};',
					
				],
			]
		);
        
         $this->end_controls_tab();
         $this->end_controls_tabs();		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_style',
			[
				'label' => __( 'Content', 'rekko-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'content_color',
			[
				'label' => __( 'Content Text Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-accordion-box  .qwords-accordion-details .qwords-detail-text' => 'color: {{VALUE}};',
					
				],
			]
		);

		$this->add_control(
			'content_back_color',
			[
				'label' => __( 'Background Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-accordion-box  .qwords-accordion-details .qwords-detail-text' => 'background: {{VALUE}};',
					
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_icon_style',
			[
				'label' => __( 'Icon', 'rekko-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'icon_active_color',
			[
				'label' => __( 'Active Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-accordion-box .qwords-ad-title .ad-title-text i.inactive' => 'color: {{VALUE}};',
					
				],
			]
		);

		$this->add_control(
			'icon_inactive_color',
			[
				'label' => __( 'Inactive Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-accordion-box .qwords-ad-title .ad-title-text i.active' => 'color: {{VALUE}};',
					
				],
			]
		);
		$this->add_responsive_control(
			'font_size_21Bupaqvc',
			[
				'label' => __( 'Font Size', 'plugin-domain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				
				'selectors' => [
					'{{WRAPPER}} .qwords-ad-title .ad-title-text i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_border_style',
			[
				'label' => __( 'Border', 'rekko-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'has_border',
			[
				'label' => __( 'Border?', 'rekko-core' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'label_off',
				'yes' => __( 'yes', 'rekko-core' ),
				'no' => __( 'no', 'rekko-core' ),
			]
        );
        $this->add_control(
			'border_style',
				[
					'label' => __( 'Border Style', 'rekko-core' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'none',
					'options' => [
						'solid'  => __( 'Solid', 'rekko-core' ),
						'dashed' => __( 'Dashed', 'rekko-core' ),
						'dotted' => __( 'Dotted', 'rekko-core' ),
						'double' => __( 'Double', 'rekko-core' ),
						'outset' => __( 'outset', 'rekko-core' ),
						'groove' => __( 'groove', 'rekko-core' ),
						'ridge' => __( 'ridge', 'rekko-core' ),
						'inset' => __( 'inset', 'rekko-core' ),
						'hidden' => __( 'hidden', 'rekko-core' ),
						'none' => __( 'none', 'rekko-core' ),
						
					],
					'condition' => [
					'has_border' => 'yes',
					],
					'selectors' => [
						'{{WRAPPER}} .qwords-accordion-block .qwords-accordion-box' => 'border-style: {{VALUE}};',
						
					],
				]
			);

		$this->add_control(
			'border_active_color',
			[
				'label' => __( 'Active Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-accordion-block .qwords-accordion-box.qwords-active' => 'border-color: {{VALUE}};',
					
				],
				'condition' => [
					'has_border' => 'yes',
				],
			]
		);

		$this->add_control(
			'border_inactive_color',
			[
				'label' => __( 'Inactive Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-accordion-block .qwords-accordion-box' => 'border-color: {{VALUE}};',
					
				],
				'condition' => [
					'has_border' => 'yes',
				],
			]
		);

		
		$this->add_control(
			'border_width',
			[
				'label' => __( 'Border Width', 'rekko-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .qwords-accordion-block .qwords-accordion-box' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'has_border' => 'yes',
				],
			]
		);
		$this->add_control(
			'border_radius_Pa756UR',
			[
				'label' => __( 'Border Radius', 'rekko-core' ),
				'condition' => [
					'has_border' => 'yes',
					],
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}}  .qwords-section-title-box .qwords-section-sub-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				
			]
		);
		$this->add_responsive_control(
			'margin_21Bupac',
			[
				'label' => __( 'Margin', 'rekko-core' ),
				'condition' => [
					'has_border' => 'yes',
					],
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}}  .qwords-section-title-box .qwords-section-sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				
			]
		);
		$this->add_responsive_control(
			'padding_21Bupac',
			[
				'label' => __( 'Padding', 'rekko-core' ),
				'condition' => [
					'has_border' => 'yes',
					],
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}}  .qwords-section-title-box .qwords-section-sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				
			]
		);


		$this->end_controls_section();

	}
	
	protected function render() {
		$settings = $this->get_settings();
       if($settings['accordion_style'] == '1')
		{
			require plugin_dir_path( __FILE__ ) . 'style-1.php';
		}

        ?>
        	<script type="text/javascript">
        		 /*------------------------
                Accordion
                --------------------------*/
                jQuery('.qwords-accordion-block .qwords-accordion-box .qwords-accordion-details').hide();
                jQuery('.qwords-accordion-block .qwords-accordion-box:first').addClass('qwords-active').children().slideDown('slow');
                jQuery('.qwords-accordion-block .qwords-accordion-box').on("click", function() {
                    if (jQuery(this).children('div.qwords-accordion-details').is(':hidden')) {
                        jQuery('.qwords-accordion-block .qwords-accordion-box').removeClass('qwords-active').children('div.qwords-accordion-details').slideUp('slow');
                        jQuery(this).toggleClass('qwords-active').children('div.qwords-accordion-details').slideDown('slow');
                    }
                });

                

        	</script>
        <?php 
    }	    
		
}

Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Accordion() );