<?php
namespace Elementor;
use Rekko\Elementor_widgets\Rekko_Elementor_Init as SCEW;

if (!defined('ABSPATH')) {
	exit;
}
class circle_progress extends Widget_Base {
	public function get_name() {
		return __('circle_progress', 'rekko-core');
	}
	public function get_title() {
		return __('Circle Progress', 'rekko-core');
	}
	public function get_categories() {
 		return [ SCEW::get_category() ];
    }
	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-loading';
	}
	protected function register_controls() {
		$this->start_controls_section(
			'section',
			[
				'label' => __( 'Style', 'rekko-core' ),
			]
		);
		$this->add_control(
            'circle_style',
			[
				'label'      => __( 'Circle style', 'rekko-core' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => '1',
				'options'    => [
					'1'       => __( 'Style-1', 'rekko-core' ),
					
				],
			]
		);
        $this->end_controls_section();
	
		$this->start_controls_section(
			'section_image',
			[
				'label' => __('Progress', 'rekko-core'),
			]
		);
		$this->add_control(
			'title_text',
			[
				'label' => __('Title', 'rekko-core'),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => __('This is Simple Title', 'rekko-core'),
				'placeholder' => __('Enter your title ', 'rekko-core'),
				'label_block' => true,
			]
		);

		$this->add_control(
		'sub_title_text',
			[
				'label' => __('Sub Title', 'rekko-core'),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => __('This is Simple Sub Title', 'rekko-core'),
				'placeholder' => __('Enter your sub title', 'rekko-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'description_text',
			[
				'label' => __('Description', 'rekko-core'),
				'type' => Controls_Manager::TEXTAREA,
				'dynamic' => [
					'active' => true,
				],
				
				'label_block' => true,
			]
		);
		
		$this->add_control('alternative',
            array(
                'label'        => esc_html__('Alternative section','thegov-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'default' => 'no',
                'true'     => esc_html__( 'yes', 'thegov-core' ),
                'false'    => esc_html__( 'no', 'thegov-core' ),
                'return_value' => 'true',
                
            )
        );
		$this->add_responsive_control(
			'progress_number',
			[
				'label' => __('Progress Number', 'rekko-core'),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 90,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
			]
		);
		$this->add_responsive_control(
			'progress_size',
			[
				'label' => __('size', 'rekko-core'),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 110,
				],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 1024,
					],
				],
			]
		);
		
		$this->add_responsive_control(
			'thickness',
			[
				'label' => __('Thickness', 'rekko-core'),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 12,
				],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 100,
					],
				],
			]
		);
		$this->add_control(
			'fill_color',
			[
				'label' => __('Fill Color', 'rekko-core'),
				'type' => Controls_Manager::COLOR,
				
			]
		);
		$this->add_control(
			'empty_color',
			[
				'label' => __('Empty Color', 'rekko-core'),
				'type' => Controls_Manager::COLOR,
				
			]
		);
		$this->add_control(
			'pencertage_color',
			[
				'label' => __('Pencertage Color', 'rekko-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
								'{{WRAPPER}} .qwords-circle-progress .qwords-progress-count' => 'color: {{VALUE}};',
					
				],
				
			]
		);
		$this->add_control(
			'Text_color',
			[
				'label' => __('text Color', 'rekko-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
								'{{WRAPPER}} .qwords-circle-progress .qwords-progress-title ' => 'color: {{VALUE}};',
								
					
				],
				
			]
		);

		$this->add_control(
			'sub_title_color',
			[
				'label' => __('Sub Title Color', 'rekko-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
								'{{WRAPPER}} .qwords-circle-progress .qwords-progress-subtitle ' => 'color: {{VALUE}};',
								
					
				],
				
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label' => __('Description Color', 'rekko-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
								'{{WRAPPER}} .qwords-circle-progress .qwords-progress-desc' => 'color: {{VALUE}};',
					
				],
				
			]
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings();
		if($settings['circle_style'] == '1')
		{
				require plugin_dir_path( __FILE__ ) . 'style-1.php';	
		}
		
		if (Plugin::$instance->editor->is_edit_mode()): ?>
			<script>
				jQuery('.qwords-circle-progress-bar').each(function() {
					var number = jQuery(this).data('skill-level');
					var empty_color = jQuery(this).data('empty-color');
					var fill_color = jQuery(this).data('fill-color');
					var size = jQuery(this).data('size');
					jQuery(this).circleProgress({
						value: '0.' + number,
						size: size,
						emptyFill: empty_color,
						fill: {
							color: fill_color
						}
					}).on('circle-animation-progress', function(event, progress) {
						jQuery(this).find('.qwords-progress-count').html(Math.round(number * progress) + '%');
					});
				});
			</script>
		<?php endif;
	}
}
Plugin::instance()->widgets_manager->register_widget_type(new \Elementor\circle_progress());