<?php
namespace Elementor; 
use Rekko\Elementor_widgets\Rekko_Elementor_Init as SCEW;

if ( ! defined( 'ABSPATH' ) ) exit; 

class Pt_Infobox extends Widget_Base {

	public function get_name() {
		return __( 'infobox', 'rekko-core' );
	}

	public function get_title() {
		return __( 'Infobox', 'rekko-core' );
	}

	public function get_categories() {
		return [ SCEW::get_category() ];
    }

	/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-info-box';
	}
     


	protected function register_controls() {
		$this->start_controls_section(
			'sectioninfobox',
			[
				'label' => __( 'Style', 'rekko-core' ),
			]
		);
		$this->add_control(
			'infobox_style',
			[
				'label' => __( 'Infobox Style', 'rekko-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1'  => __( 'Style 1', 'rekko-core' ),
				],
			]
		);


        $this->end_controls_section();

		$this->start_controls_section(
			'sectionftf',
			[
				'label' => __( 'Infobox', 'rekko-core' ),
			]
		);

        $this->add_control(
			'image_style',
			[
				'label'      => __( 'Choose Image/Icon', 'rekko-core' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'none',
				'options'    => [
					'none'       => __( 'None', 'rekko-core' ),
					'1'          => __( 'Image', 'rekko-core' ),
					'2'          => __( 'Icon', 'rekko-core' ),

				],
			]
		);
		$this->add_control(
			'info_image',
			[
				'label' => __( 'Choose Image', 'rekko-core'),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'condition'=>[
					'image_style' => '1'
				],
			]
		);
		$this->add_control(
			'selected_icon',
			[
				'label' => __( 'Select Icon', 'rekko-core' ),
				'type' => Controls_Manager::ICONS,
				'label_block' => true,
				'default' => [
					'value' => 'fas fa-check',
					'library' => 'fa-solid',
				],
                'fa4compatibility' => 'icon',
				'separator' => 'before',
				'condition'=>[
					'image_style' => '2'
				],
			]
		);

		$this->add_control(
			'single_icon',
			[
				'label' => __( 'Background Icon', 'rekko-core' ),
				'type' => Controls_Manager::ICONS,
				'label_block' => true,
				'default' => [
					'value' => 'fas fa-check',
					'library' => 'fa-solid',
				],
                'fa4compatibility' => 'icon',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'title_text',
			[
				'label' => __( 'Title', 'rekko-core' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => __( 'This is sample title', 'rekko-core' ),
				'placeholder' => __( 'Enter your title', 'rekko-core' ),
				'label_block' => true,
			]
        );

        $this->add_control(
			'title_tag',
			[
				'label' => __( 'Title Tag', 'rekko-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h5',
				'options' => [
					'h1'  => 'h1',
					'h2'  => 'h2',
					'h3'  => 'h3',
					'h4'  => 'h4',
					'h5'  => 'h5',
					'h6'  => 'h6',
					'p'  => 'p',
					'span'  => 'span',

				],

			]

		);

		$this->add_control(
			'desc_content',
			[
				'label' => __( 'Enable/disable description', 'rekko-core' ),
				'type' => Controls_Manager::SWITCHER ,
				'label_on' => __( 'Show', 'rekko-core' ),
				'label_off' => __( 'Hide', 'rekko-core' ),
				'return_value' => 'yes',
				'default' => 'yes',

			]
		);

		$this->add_control(
			'description_text',
			[
				'label' => __( 'Content', 'rekko-core' ),
				'type' => Controls_Manager::WYSIWYG,
				'dynamic' => [
					'active' => true,
				],
				'default' => __( 'Enter your Description here', 'rekko-core' ),
				'placeholder' => __( 'Enter your description', 'rekko-core' ),
				'separator' => 'before',
				'rows' => 10,
				'show_label' => true,
				'condition' => [
					'desc_content' => 'yes',
				]
			]
		);
		$this->add_control(
			'show_button',
			[
				'label' => __( 'Show/Hide button', 'rekko-core' ),
				'type' => Controls_Manager::SWITCHER,
				'yes' => __( 'yes', 'rekko-core' ),
				'no' => __( 'no', 'rekko-core' ),
			]
        );
        $this->end_controls_section();



        $this->start_controls_section(
			'section__2p08cZ',
			[
				'label' => __( 'Alignment', 'rekko-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		 $this->add_responsive_control(
			'content_align',
			[
				'label' => __( 'Alignment', 'rekko-core' ),
				'type' => Controls_Manager::CHOOSE,
				'default'    => 'left',
				'options' => [
					'left' => [
						'title' => __( 'Left', 'rekko-core' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'rekko-core' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'rekko-core' ),
						'icon' => 'eicon-text-align-right',
					]
		 		],
		 		'selectors' => [
					'{{WRAPPER}} .qwords-info-box' => 'text-align: {{VALUE}};',
				]
			]
        );
		$this->end_controls_section();

		$this->start_controls_section(
			'section__2108cy',
			[
				'label' => __( 'Content', 'rekko-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_control(
			'head_title',
			[
				'label' => __( 'Title', 'rekko-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		 $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __( 'Typography', 'rekko-core' ),
				'selector' => '{{WRAPPER}} .qwords-info-box .qwords-info-title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'rekko-core' ),

				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-info-box .qwords-info-title' => 'color: {{VALUE}};',
		 		],


			]
		);

		$this->add_control(
			'head_num',
			[
				'label' => __( 'Number', 'rekko-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',

			]
		);

		 $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'number_typography',
				'label' => __( 'Typography', 'rekko-core' ),
				'selector' => '{{WRAPPER}} .qwords-info-box .qwords-info-call h5',
			]
		);

		$this->add_control(
			'number_color',
			[
				'label' => __( 'Color', 'rekko-core' ),

				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-info-box .qwords-info-call h5' => 'color: {{VALUE}};',
		 		],


			]
		);

		$this->add_control(
			'head_desc',
			[
				'label' => __( 'Description', 'rekko-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		 $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description_typography',
				'label' => __( 'Typography', 'rekko-core' ),
				'selector' => '{{WRAPPER}} .qwords-info-box .qwords-infobox-description',
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label' => __( 'Color', 'rekko-core' ),

				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-info-box .qwords-infobox-description' => 'color: {{VALUE}};',

		 		],


			]
		);
		 $this->end_controls_section();

		  $this->start_controls_section(
			'section__2456Z1',
			[
				'label' => __( 'Icon', 'rekko-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		 $this->add_control(
			'head_icon',
			[
				'label' => __( 'Background Icon', 'rekko-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		  $this->add_control(
			'icon_size_512832y67',
			[
				'label' => __( 'Typography', 'rekko-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],

				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .qwords-info-box .qwords-info-box-right-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);


		$this->add_control(
					'icon_color',
					[
						'label' => __( 'Color', 'rekko-core' ),

						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .qwords-info-box .qwords-info-box-right-icon i' => 'color: {{VALUE}};',
				 		],


					]
				);


		$this->add_control(
			'headss_icon',
			[
				'label' => __( 'Icon', 'rekko-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'image_style' => '2',
				],
			]
		);

		  $this->add_control(
			'iconss_size_512832y67',
			[
				'label' => __( 'Typography', 'rekko-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],

				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .qwords-info-box .qwords-info-box-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'image_style' => '2',
				],				
			]
		);


		$this->add_control(
				'iconss_color',
				[
					'label' => __( 'Color', 'rekko-core' ),

					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .qwords-info-box .qwords-info-box-icon i' => 'color: {{VALUE}};',
				],
				'condition' => [
					'image_style' => '2',
				],

					]
				);


		 $this->end_controls_section();

	// Add Button
		$this->start_controls_section(
			'section_Jnza436755QH5b77yuyo',
			[
				'label' => __( 'Button', 'rekko-core' ),

			]
		);
		$btn = new Button_Controls();
		$btn->get_btn_controls($this);


	 // Button End
	}

	protected function render() {
		$settings = $this->get_settings();
       if($settings['infobox_style'] == '1')
		{
			require plugin_dir_path( __FILE__ ) . 'style-1.php';
		}

    }

}

Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Pt_Infobox() );