<?php
namespace Elementor;
use Rekko\Elementor_widgets\Rekko_Elementor_Init as SCEW;
if ( ! defined( 'ABSPATH' ) ) exit;

class Lab_Progressbar extends Widget_Base {

	public function get_name() {
		return __( 'lab_progressbar', 'rekko-core' );
	}

	public function get_title() {
		return __( 'Progressbar', 'rekko-core' );
	}

	public function get_categories() {
		return [ SCEW::get_category() ];
    }

/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-skill-bar';
	}



	protected function register_controls() {
		$this->start_controls_section(
			'section_hiadk',
			[
				'label' => __( 'Style', 'rekko-core' ),
			]
		);
		$this->add_control(
			'Progressbar_style',
			[
				'label' => __( 'Progressbar Style', 'rekko-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1'  => __( 'Style 1', 'rekko-core' ),
					// '2'  => __( 'Style 2', 'rekko-core' ),

				],
			]
		);


        $this->end_controls_section();
		$this->start_controls_section(
			'section55645',
			[
				'label' => __( 'Progressbar', 'rekko-core' ),
			]
		);

        $repeater = new Repeater();
        $repeater->add_control(
			'section_title',
			[
				'label' => __( 'Title', 'rekko-core' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
				'default' => __( 'Add Your Title Text Here', 'rekko-core' ),
			]
		);

		$repeater->add_control(
			'tab_score',
			[
				'label' => __( 'Score out of 100', 'rekko-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 50,
				],

			]
		);
		 $this->add_control(
			'progress_bar',
			[
				'label' => __( 'Add Progress Bar', 'rekko-core' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'section_title' => __( 'List Items', 'rekko-core' ),
						'tab_score'=>__( '50', 'rekko-core' ),

					]

				],
				'title_field' => '{{{ section_title }}}',
				'figure_field' => '{{{ tab_score }}}',
			]
        );
		  $this->add_control(
			'data_height',
			[
				'label' => __( 'height', 'rekko-core' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);



		 $this->end_controls_section();

		$this->start_controls_section(
			'section_progress_style',
			[
				'label' => __( 'Content', 'rekko-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'head_pbc',
			[
				'label' => __( 'Progress Bar Background', 'rekko-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'progress_back_color',
			[
				'label' => __( 'Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-progressbar-style-1 .qwords-progress-bar .bar' => 'background-color: {{VALUE}}!important;',
					'{{WRAPPER}} .qwords-progressbar-style-2 .qwords-progress-bar .bar' => 'background-color: {{VALUE}}!important;',

				],
			]
		);

		$this->add_control(
			'head_title',
			[
				'label' => __( 'Title', 'rekko-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_text_typography',
				'label' => __( 'Typography', 'rekko-core' ),
				'selector' => '{{WRAPPER}} .qwords-progressbar-box .progress-title',
			]
		);


		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-progressbar-box .progress-title' => 'color: {{VALUE}};',

				],
			]
		);

		$this->add_control(
			'head_num',
			[
				'label' => __( 'Number', 'rekko-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'number_text_typography',
				'label' => __( 'Typography', 'rekko-core' ),
				'selector' => '{{WRAPPER}} .qwords-progressbar-box .progress-value',
			]
		);

		$this->add_control(
			'number_color',
			[
				'label' => __( 'Color', 'rekko-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .qwords-progressbar-box .progress-value' => 'color: {{VALUE}};'


				],
			]
		);

		$this->add_control(
			'head_border_type',
			[
				'label' => __( 'Border', 'rekko-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_responsive_control(
			'progressbar_height',
			[
				'label' => __( 'Height', 'rekko-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .qwords-progress-bar' => 'height: {{SIZE}}{{UNIT}};line-height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		 $this->add_responsive_control(
			'progressbar_border_radius',
			[
				'label' => __( 'Border Radius', 'rekko-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .qwords-progress-bar' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();

     	require plugin_dir_path( __FILE__ ) . 'style-1.php';

        if ( ! Plugin::$instance->editor->is_edit_mode() ) {

			?>

			<script>
						 /*------------------------
                Progress Bar
                --------------------------*/
                 jQuery('.qwords-progress-bar > span').each(function() {

                    var progress_bar = jQuery(this);
                    var width = jQuery(this).data('width');
                    progress_bar.css({
                        'transition': 'width 2s'
                    });
                    jQuery('.progress-value').css({'transition': 'margin 2s'});

                    setTimeout(function() {
                        jQuery(this).show(function() {
                            progress_bar.css('width', width + '%');
                        });
                    }, 500);

                    setTimeout(function() {
                        jQuery('.qwords-progressbar-style-2 .progress-value').show(function() {
                            jQuery('.qwords-progressbar-style-2 .progress-value').css('margin-left', width + 'px');
                        });
                    }, 500);

                    setTimeout(function() {
                        jQuery('.qwords-progressbar-style-3 .progress-tooltip').show(function() {
                            jQuery('.qwords-progressbar-style-3 .progress-tooltip').css('margin-left', width + 'px');
                        });
                    }, 500);
                });
			</script>

		<?php
		}
    }

}

Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Lab_Progressbar() );